@@ -1,7 +1,8 @@
+#%%
 import pandas as pd
 import regex as re
 import numpy as np
-from datetime import date
+from datetime import date,datetime
 from tqdm.auto import tqdm
 import os
 import logging
@@ -190,6 +191,7 @@ class QualityAssessments:
         
         error_message, error_occured = '', False
         new_dict = {}
+        new_dict['datetime'] = pd.to_datetime(datetime.now())
         for col in cols_to_check:
             new_dict[col] = df[col].sum()
 
@@ -198,13 +200,16 @@ class QualityAssessments:
 
         if os.path.isdir('Historic df Comparison (Do Not Delete)') == False:
             os.mkdir('Historic df Comparison (Do Not Delete)')
-        if os.path.exists(f'Historic df Comparison (Do Not Delete)/{name_of_df}_previous_totals') ==False:
+        if os.path.exists(f'Historic df Comparison (Do Not Delete)/{name_of_df}_previous_totals.json') ==False:
             self.util.pickle_data(new_dict,f'{name_of_df}_previous_totals',folder='Historic df Comparison (Do Not Delete)/')
             logger.info(f"Creation of {name_of_df}_previous_totals")
             logger.info(new_dict)
             return
         else:
-            old_dict = self.util.unpickle_data(f'{name_of_df}_previous_totals',folder='Historic df Comparison (Do Not Delete)')
+            #old_dict = self.util.unpickle_data(f'{name_of_df}_previous_totals',folder='Historic df Comparison (Do Not Delete)')
+            old_dict_file = self.util.read_json(f'{name_of_df}_previous_totals.json',folder='Historic df Comparison (Do Not Delete)',
+                                                    file_type='json')
+            old_dict = old_dict_file[-1] #Grab the lastest entry in the json file, descending date order
         
         for key, value in old_dict.items():
             if key == 'Columns':
@@ -230,7 +235,9 @@ class QualityAssessments:
             logger.info('ERROR' + error_message) #if error messages has been added to then log it
         if raise_exceptions and error_occured:
             raise Exception(error_message)
-        self.util.pickle_data(new_dict,f'{name_of_df}_previous_totals',folder='Historic df Comparison (Do Not Delete)/')
+        #self.util.pickle_data(new_dict,f'{name_of_df}_previous_totals',folder='Historic df Comparison (Do Not Delete)/')
+        self.util.write_json(new_dict,f'{name_of_df}_previous_totals',file_type='append',
+                             folder='Historic df Comparison (Do Not Delete)/')
         
         return error_message
     
